{% extends 'allianceauth/base.html' %}

{% block content %}
    <div class="col-lg-12">
        <h1 class="page-header text-center">Links Audit</h1>
        <nav class="navbar navbar-default">
            <div class="container-fluid">
                <ul class="nav navbar-nav">
                    <li class="dropdown">
                        <a href="#" id="dLabel" class="dropdown-toggle" role="button" data-toggle="dropdown" aria-haspopup="false" aria-expanded="false">Corporations<span class="caret"></span></a>
                        <ul class="dropdown-menu" role="menu" aria-labelledby="dLabel">
                            {% for corp in available %}
                                <li>
                                    <a href="{% url 'charlink:audit_corp' corp.corporation_id %}">{{ corp.corporation_name }}</a>
                                </li>
                            {% endfor %}
                        </ul>
                    </li>
                    <li class="dropdown">
                        <a href="#" id="appDrop" class="dropdown-toggle" role="button" data-toggle="dropdown" aria-haspopup="false" aria-expanded="false">Apps<span class="caret"></span></a>
                        <ul class="dropdown-menu" role="menu" aria-labelledby="appDrop">
                            {% for app, data in available_apps.items %}
                                <li>
                                    <a href="{% url 'charlink:audit_app' app %}">{{ data.field_label }}</a>
                                </li>
                            {% endfor %}
                        </ul>
                    </li>
                </ul>
                <form class="navbar-form navbar-right" role="search" action="{% url 'charlink:search' %}" method="GET">
                    <div class="form-group">
                        <input type="text" class="form-control" name="search_string" placeholder="{% if search_string %}{{ search_string }}{% else %}Search character...{% endif %}">
                    </div>
                </form>
            </div>
        </nav>
        {% block auditblock %}{% endblock auditblock %}
    </div>
{% endblock content %}